<?php

switch ($messaggio) {

case "Configura e personalizza HotelDruid":	$messaggio = "Hoteldruid konfigurieren und anpassen"; break;
case "Scegli la lingua":  			$messaggio = "Sprache w&auml;hlen"; break;
case "cambia la lingua":  			$messaggio = "Sprache &auml;ndern"; break;
case "Tabella con tutte le prenotazioni":  	$messaggio = "Tabelle mit allen Reservierungen"; break;
case "Scegli le colonne da far comparire":  	$messaggio = "W&auml;hlen Sie die Spalten die angezeigt werden sollen"; break;
case "n° di settimane":  			$messaggio = "Wochenanzahl"; break;
case "n° di giorni":  				$messaggio = "Tagesanzahl"; break;
case "caparra":  				$messaggio = "Anzahlung"; break;
case "pagato":  				$messaggio = "bezahlt"; break;
case "resto da pagare":  			$messaggio = "Rest zu zahlen"; break;
case "n° di persone":  				$messaggio = "Personenanzahl"; break;
case "commento":  				$messaggio = "Kommentar"; break;
case "costo aggiuntivo unico":  		$messaggio = "einmaliger Zuschlag"; break;
case "abbreviazione":  				$messaggio = "Abk&uuml;rzung"; break;
case "costo aggiuntivo settimanale":  		$messaggio = "w&ouml;chentliche Aufschl&auml;ge"; break;
case "costo aggiuntivo giornaliero":  		$messaggio = "t&auml;gliche Aufschl&auml;ge"; break;
case "cambia le colonne":  			$messaggio = "Spalten &auml;ndern"; break;
case "Tabelle dei mesi":  			$messaggio = "Monatstabellen"; break;
case "Numero di tabelle del 2° tipo":  		$messaggio = "Nummer der 2. Tabellentype"; break;
case "cambia":  				$messaggio = "&auml;ndern"; break;
case "Torna al menù principale":  		$messaggio = "Hauptmen&uuml;"; break;
case "a":  					$messaggio = "in"; break;
case "La lingua è stata cambiata":  		$messaggio = "Sprache wurde ge&auml;ndert"; break;
case "La valuta è stata cambiata":  		$messaggio = "W&auml;hrung wurde ge&auml;ndert"; break;
case "Le colonne sono state cambiate":  	$messaggio = "Spalten wurden ge&auml;ndert"; break;
case "Il numero di tabelle è stato cambiato":  	$messaggio = "Die Anzahl der Tabellen wurden ge&auml;ndert"; break;
case "Documenti":  				$messaggio = "Dokumente"; break;
case "documento":  				$messaggio = "Dokument"; break;
case "cambia i nomi dei documenti":  		$messaggio = "Dokumentnamen &auml;ndern"; break;
case "I nomi dei documenti sono stati cambiati":	$messaggio = "Dokumentnamen wurden ge&auml;ndert"; break;
case "Formato di visualizzazione dei soldi":  	$messaggio = "W&auml;hrung - Anzeigeformat"; break;
case "cambia formato":  			$messaggio = "Format &auml;ndern"; break;
case "Il formato di visualizzazione dei soldi è stato cambiato":	$messaggio = "W&auml;hrung - Anzeigeformat wurde ge&auml;ndert"; break;
case "Le date sono sbagliate":  		$messaggio = "Daten sind falsch"; break;
case "Le date dei menù a tendina sono state cambiate":	$messaggio = "Daten f&uuml;r Drop Down Men&uuml; wurden ge&auml;ndert"; break;
case "Scegli le date":  			$messaggio = "Daten ausw&auml;hlen"; break;
case "nei menù a tendina":  			$messaggio = "in Drop-Down Men&uuml;s"; break;
case "dal":  					$messaggio = "von"; break;
case "al":  					$messaggio = "zu"; break;
case "Tronca i cognomi nelle tabelle dopo ":	$messaggio = "Nachnamen abschneiden in der Tabelle nach "; break;
case "caratteri per colonna":  			$messaggio = "Zeichen pro Spalte"; break;
case "La lunghezza dei cognomi nelle tabelle dei mesi è stata cambiata":                                                 $messaggio = "L&auml;nge der Nachnamen in der Monatstabelle wurden ge&auml;ndert"; break;
case "Cambia il numero delle tariffe":  	$messaggio = "Anzahl der Preise &auml;ndern"; break;
case "per l'anno":  				$messaggio = "f&uuml;r das Jahr"; break;
case "Il numero delle tariffe è stato cambiato":$messaggio = "Die Anzahl der Preise wurden ge&auml;ndert"; break;
case "Il numero di tariffe è sbagliato":  	$messaggio = "Die Anzahl der Preise ist falsch"; break;
case "Sistema di backup":  			$messaggio = "Sicherungssystem"; break;
case "Il numero delle righe è sbagliato":  	$messaggio = "Die Anzahl der Zeilen ist falsch"; break;
case "Cambia il numero delle righe":  		$messaggio = "Anzahl der Zeilen &auml;ndern"; break;
case "Il numero delle righe della tabella con tutte le prenotazioni è stato cambiato":                                                 $messaggio = "Die Anzahl der Zeilen von der Tabelle mit allen Reservierungen wurden ge&auml;ndert."; break;
case "Il numero delle righe della tabella con la storia delle entrate e delle uscite è stato cambiato":                                                 $messaggio = "Die Anzahl der Zeilen von der Tabelle mit allen eingegangen Zahlungen wurden ge&auml;ndert."; break;
case "Tabella con la storia delle entate e uscite":	$messaggio = "Tabelle f&uuml;r eingegangene Zahlungen"; break;
case "Il formato di visualizzazione delle date è stato cambiato":	$messaggio = "Datums Anzeigeformat wurde ge&auml;ndert"; break;
case "Formato di visualizzazione delle date":	$messaggio = "Datums Anzeigeformat"; break;
case "Tabella con tutti i clienti":  		$messaggio = "Tabelle mit allen Kunden"; break;
case "Il numero delle righe della tabella con tutti i clienti è stato cambiato":	$messaggio = "Die Anzahl der Zeilen von der Tabelle mit allen Kunden wurden ge&auml;ndert"; break;
case "Si deve sceliere qualche dato da inserire nella colonna gruppo":	$messaggio = "Sie m&uuml;ssen Daten ausw&auml;hlen die in die Gruppenspalte eingef&uuml;gt werden sollen."; break;
case "Si deve inserire il nome della colonna gruppo":	$messaggio = "Sie m&uuml;ssen der Gruppenspalte einen Namen geben"; break;
case "La colonna gruppo è stata aggiunta":  	$messaggio = "Die Gruppenspalte wurde hinzugef&uuml;gt"; break;
case "Aggiungi una colonna gruppo":  		$messaggio = "Gruppenspalte hinzuf&uuml;gen"; break;
case "Aggiungi colonna gruppo":  		$messaggio = "Gruppenspalte hinzuf&uuml;gen"; break;
case "chiamata":  				$messaggio = "genannt"; break;
case "con":  					$messaggio = "mit"; break;
case "colonna gruppo":  			$messaggio = "Gruppenspalte"; break;
case "separatore":  				$messaggio = "Trenner"; break;
case "spazio":  				$messaggio = "Leerzeichen"; break;
case "trattino":  				$messaggio = "Bindestrich"; break;
case "a capo":  				$messaggio = "neue Zeile"; break;
case "Pagine per il sito web":  		$messaggio = "Webseiten"; break;
case "nome della tariffa":  			$messaggio = "Bezeichnung des Tarifs"; break;
case "data di inserimento":  			$messaggio = "Eintragsdatum"; break;
case "tariffa completa":  			$messaggio = "Gesamtpreis"; break;
case "Gestione utenti":  			$messaggio = "Benutzerverwaltung"; break;
case "Personalizzazioni dell'utente":  		$messaggio = "Pers&ouml;nliche Einstellungen des Benutzers"; break;
case "Cambia":  				$messaggio = "&Auml;ndere"; break;
case "quelle di":  				$messaggio = "diese von"; break;
case "Importa i nomi dei documenti":  		$messaggio = "Dokumentnamen importieren"; break;
case "Importa":  				$messaggio = "Importieren"; break;
case "dell'utente":  				$messaggio = "von Benutzer"; break;
case "I minuti di durata di sessioni e transazioni sono stati cambiati":	$messaggio = "Die Dauer von Sessions und Transaktionen in Minuten wurde ge&auml;ndert."; break;
case "Le ore di anticipo dell'inizio delle prenotazioni sono state cambiate":	$messaggio = "Vorlaufzeit in Stunden in denen Reservierungen nicht akzeptiert werden wurde ge&auml;ndert"; break;
case "Minuti dopo i quali considerare scadute sessioni e transazioni non aggiornate":	$messaggio = "G&uuml;ltigkeitsdauer von Sessions und Transaktionen in Minuten, wenn sie nicht aktualisiert werden"; break;
case "Numero di ore di cui anticipare il momento in cui si considera iniziata una prenotazione":	$messaggio = "Vorlaufzeit in Stunden in denen Reservierungen nicht akzeptiert werden"; break;
case "utente":  				$messaggio = "Benutzer"; break;
case "Interconnessioni":  			$messaggio = "Verbindungen"; break;
case "Assegnazione automatica disattivata":  	$messaggio = "Automatische Zuweisung deaktiviert"; break;
case "Assegnazione automatica attivata":  	$messaggio = "Automatische Zuweisung aktiviert"; break;
case "Attiva":  				$messaggio = "Aktivieren"; break;
case "Disattiva":  				$messaggio = "Deaktivieren"; break;
case "Scegli il tema grafico":  		$messaggio = "Grafik-Schema ausw&auml;hlen"; break;
case "Il tema grafico è stato cambiato":  	$messaggio = "Das Grafik-Schema wurde ge&auml;ndert"; break;
case "Registrazione degli orari di entrata ed uscita attivata":	$messaggio = "Registrierung von An- und Abreisezeit angeschaltet"; break;
case "Registrazione degli orari di entrata ed uscita disattivata":  $messaggio = "Registrierung von An- und Abreisezeit abgeschaltet"; break;
case "Le ore di differenza con l'orario del server sono state cambiate": $messaggio = "Zeitdifferenz zur Serverzeit wurde ge&auml;ndert"; break;
case "Ore di differenza con l'orario del server": 	$messaggio = "Zeitdifferenz lokale Zeit zur Serverzeit"; break;
case "ora attuale":  				$messaggio = "aktuelle Uhrzeit (Stunde)"; break;
case "numero":  				$messaggio = "lfd. Nummer"; break;
case "cognome cliente":  			$messaggio = "Nachname Gast"; break;
case "data iniziale":  				$messaggio = "Ankunftsdatum"; break;
case "data finale":  				$messaggio = "Abreisedatum"; break;
case "Le colonne necessarie sono state cambiate":	$messaggio = "Die notwendigen Spalten wurden ver&auml;ndert"; break;
case "Non mostrare prenotazioni che non hanno almeno una di queste colonne necessarie (non selezionarene per mostrare tutte)":	$messaggio = "Reservierungen, die nicht mindestens eine dieser ben&ouml;tigten Spalten aufweisen nicht anzeigen (um alle zu zeigen keine ausw&auml;hlen)"; break;
case "cambia le colonne necessarie":  		$messaggio = "&auml;ndere ben&ouml;tigte Spalten"; break;
case "Metodo di pagamento eliminato":  		$messaggio = "Zahlungsart gel&ouml;scht"; break;
case "Nuovo metodo di pagamento aggiunto":  	$messaggio = "Neue Zahlungsart angelegt"; break;
case "Metodi di pagamento":  			$messaggio = "Zahlungsarten"; break;
case "elimina":  				$messaggio = "l&ouml;schen"; break;
case "aggiungi":  				$messaggio = "hinzuf&uuml;gen"; break;
case "Quadro indicativo disponibilità":  	$messaggio = "Verf&uuml;gbarkeits&uuml;bersicht"; break;
case "non mostrare":  				$messaggio = "nicht anzeigen"; break;
case "Il modo di visualizzazione del quadro di disponibilità è stato cambiato":	$messaggio = "Die Verf&uuml;gbarkeits&uuml;bersichtsanzeige wurde ver&auml;ndert"; break;
case "Controllo disponibilità":  		$messaggio = "Pr&uuml;fung der Verf&uuml;gbarkeit"; break;
case "settimane di intervallo":  		$messaggio = "im Wochenabstand"; break;
case "giorni di intervallo":  			$messaggio = "im Abstand einzelner Tage"; break;
case "Giorno di inizio/fine settimana cambiato":	$messaggio = "Beginn/Ende der Woche ge&auml;ndert"; break;
case "Giorno di inizio/fine settimana nelle tabelle":	$messaggio = "Beginn/Ende der Woche in Tabellen"; break;
case "Anno":  					$messaggio = "Jahr"; break;
case "Creazione automatica del nuovo anno disattivata (importando i dati dall'anno precedente al primo login di un utente)":	$messaggio = "Automatische Erstellung des Jahres abgeschaltet (importiere Daten aus dem Vorjahr zum ersten Login eines beliebigen Nutzers)"; break;
case "Creazione automatica del nuovo anno attivata (importando i dati dall'anno precedente al primo login di un utente)":	$messaggio = "Automatische Erstellung des Jahres eingeschaltet (importiere Daten aus dem Vorjahr zum ersten Login eines beliebigen Nutzers)"; break;
case "Creazione automatica nuovo anno disattivata":	$messaggio = "Automatische Erstellung des Jahres abgeschaltet"; break;
case "Creazione automatica nuovo anno attivata":	$messaggio = "Automatische Erstellung des Jahres eingeschaltet"; break;
case "Sostituisci la parola":  			$messaggio = "Ersetze das Wort"; break;
case "Parole da sostituire":  			$messaggio = "Zu ersetzende W&ouml;rter"; break;
case "La parola da sostituire è stata aggiunta":	$messaggio = "Das zu ersetzende Wort wurde hinzugef&uuml;gt"; break;
case "La parola da sostituire è stata eliminata":	$messaggio = "Das zu ersetzende Wort wurde gel&ouml;scht"; break;
case "modifica il documento":  			$messaggio = "Dokument &auml;ndern"; break;
case "Aggiungi ai documenti":  			$messaggio = "Dokument hinzuf&uuml;gen"; break;
case "variabili personalizzate":  		$messaggio = "freie Variablen"; break;
case "Cambia il numero dei documenti":  	$messaggio = "Anzahl Dokumente &auml;ndern"; break;
case "Il numero di documenti è stato cambiato":	$messaggio = "Die Anzahl der Dokumente wurde ge&auml;ndert"; break;
case "Il numero di documenti è sbagliato":  	$messaggio = "Die Anzahl der Dokumente ist falsch"; break;
case "Indirizzo email":  			$messaggio = "E-Mail Adresse"; break;
case "Mascherare la provenienza delle email sull'envelope":	$messaggio = "Verschleierung des Absenders im elektronischen Briefumschlag"; break;
case "Il mascheramento della provenienza delle email è stato cambiato":	$messaggio = "Verschleierung des Absenders im elektronischen Briefumschlag wurde ge&auml;ndert"; break;
case "SI":  					$messaggio = "JA"; break;
case "NO":  					$messaggio = "NEIN"; break;
case "Cartelle in cui creare le pagine per il sito web":	$messaggio = "Verzeichnisse, in denen Webseiten erzeugt werden"; break;
case "alla cartella di HotelDruid, se non iniziano con /":	$messaggio = "wenn sie nicht mit / beginnen"; break;
case "Non ho i permessi di scrittura sulla cartella":	$messaggio = "Ich habe keine Schreibberechtigung im Verzeichnis"; break;
case "La cartella inserita <div style=\"display: inline; color: red;\">non esiste</div>":	$messaggio = "Das eingegebene Verzeichnis <div style=\"display: inline; color: red;\">existiert nicht</div>"; break;
case "Le cartelle dove vengono create le pagine per il sito web sono state cambiate":	$messaggio = "Die Verzeichnisse, in denen Webseiten erzeugt werden, wurden ge&auml;ndert"; break;
case "Selezionare in modo predefinito":  	$messaggio = "Als Voreinstellung ausw&auml;hlen"; break;
case "tutte le prenotazioni":  			$messaggio = "alle Reservierungen"; break;
case "prenotazioni del periodo corrente":  	$messaggio = "Reservierungen im laufenden Zeitraum"; break;
case "La selezione predefinita delle prenotazioni nella tabella con tutte le prenotazioni è stata cambiata":	$messaggio = "Die Voreinstellung der Reservierungen in der Tabelle mit allen Reservierungen wurde ge&auml;ndert"; break;
case "Numero di righe dopo cui ripetere la riga delle date":	$messaggio = "Anzahl der Zeilen nach denen eine Datumszeile angezeigt wird"; break;
case "Il numero  di righe dopo cui ripetere la riga delle date è stato cambiato":	$messaggio = "Die Anzahl der Zeilen nach denen eine Datumszeile angezeigt wird, wurde ge&auml;ndert"; break;
case "orario entrata stimato":  		$messaggio = "gesch&auml;tzte Ankunftszeit"; break;
case "Mostrare i giorni nella riga delle date?":	$messaggio = "Tage in der Datumszeile anzeigen?"; break;
case "I giorni da mostrare nella tabella dei mesi sono stati cambiati": $messaggio = "Die anzuzeigenden Tage in der Datumszeile wurde ge&auml;ndert"; break;
case "Nazioni":  				$messaggio = "Staaten"; break;
case "Elimina tutte":  				$messaggio = "Alle l&ouml;schen"; break;
case "Ripristina predefinite":  		$messaggio = "Voreinstellung wieder herstellen"; break;
case "Importa le nazioni":  			$messaggio = "Staaten importieren"; break;
case "Regioni/provincie":  			$messaggio = "Regionen"; break;
case "Importa le regioni/provincie":  		$messaggio = "Regionen importieren"; break;
case "Nazione cancellata":  			$messaggio = "Staat gel&ouml;scht"; break;
case "Regione/provincia cancellata":  		$messaggio = "Region gel&ouml;scht"; break;
case "Nuova nazione aggiunta":  		$messaggio = "Neuer Staat hinzugef&uuml;gt"; break;
case "Nazioni predefinite ripristinate":  	$messaggio = "Voreingestellter Staat wieder hergestellt"; break;
case "Nazioni cancellate":  			$messaggio = "Staaten gel&ouml;scht"; break;
case "Nazioni importate":  			$messaggio = "Staaten importiert"; break;
case "Nuova regione/provincia aggiunta":  	$messaggio = "Neue Region hinzugef&uuml;gt"; break;
case "Regioni/provincie predefinite ripristinate":	$messaggio = "Voreingestellte Regionen wieder hergestellt"; break;
case "Regioni/provincie cancellate":  		$messaggio = "Regionen gel&ouml;scht"; break;
case "Regioni/provincie importate":  		$messaggio = "Regionen importiert"; break;
case "Parentele":  				$messaggio = "Verwandtschaftsgrad"; break;
case "Importa le parentele":  			$messaggio = "Importiere Verwandtschaftsgrad"; break;
case "Parentela cancellata":  			$messaggio = "Verwandtschaftsgrad gel&ouml;scht"; break;
case "Nuova parentela aggiunta":  		$messaggio = "Neuer Verwandtschaftsgrad hinzugef&uuml;gt"; break;
case "Parentele predefinite ripristinate":  	$messaggio = "Voreingestellter Verwandtschaftsgrad wieder hergestellt"; break;
case "Parentele cancellate":  			$messaggio = "Verwandtschaftsgrad gel&ouml;scht"; break;
case "Parentele importate":  			$messaggio = "Verwandtschaftsgrad importiert"; break;
case "origine":  				$messaggio = "Herkunft"; break;
case "Origini delle prenotazioni":  		$messaggio = "Ursprung der Reservierung"; break;
case "Nuova origine delle prenotazioni aggiunta":	$messaggio = "Neuer Reservierungsursprung hinzugef&uuml;gt"; break;
case "Origine delle prenotazioni eliminata":  	$messaggio = "Reservierungsherkunft gel&ouml;scht"; break;
case "Nome combinazione":  			$messaggio = "Name der Kombination"; break;
case "prenotazioni correnti e future":  	$messaggio = "aktuelle und zuk&uuml;nftige Reservierungen"; break;
case "Personalizzazioni di <b>tutti gli utenti</b>":  	$messaggio = "Anpassung von <b>allen Benutzern</b>"; break;
case "tutti gli utenti":  			$messaggio = "Alle Benutzer"; break;
case "Personalizzazioni del gruppo":  		$messaggio = "Anpassungen der Gruppe"; break;
case "gruppo":  				$messaggio = "Gruppe"; break;
case "Log delle query di modifica generate":	$messaggio = "&Auml;nderungsprotokolle"; break;
case "da tutti gli utenti":  			$messaggio = "von allen Benutzern"; break;
case "dall'utente":  				$messaggio = "von einem Benutzer"; break;
case "dal gruppo":  				$messaggio = "von einer Gruppe"; break;
case "attivato":				$messaggio = "aktiviert"; break;
case "disattivato":				$messaggio = "deaktiviert"; break;
case "Vedi i log":  				$messaggio = "Logs ansehen"; break;
case "Log delle query di modifica effettuate dagli utenti negli ultimi":	$messaggio = "&Auml;nderungsprotokolle der Benutzer in den letzten"; break;
case "giorni":  				$messaggio = "Tagen"; break;
case "Utente":  				$messaggio = "Benutzer"; break;
case "Data":  					$messaggio = "Datum"; break;
case "Query":  					$messaggio = "Abfrage"; break;
case "Cancella tutti i log":  			$messaggio = "Alle Logs l&ouml;schen"; break;
case "Log delle query di modifica degli utenti normali disattivato":	$messaggio = "&Auml;nderungsprotokolle von normalen Benutzern deaktiviert"; break;
case "Log delle query di modifica degli utenti normali attivato":	$messaggio = "&Auml;nderungsprotokolle von normalen Benutzern aktiviert"; break;
case "Allineare la disponibilità con la data di arrivo?":	$messaggio = "Vermietung pro Tag (ja) oder pro Nacht (nein)?"; break;
case "Torna indietro":  			$messaggio = "Zur&uuml;ck"; break;
case "Documenti di identità":  			$messaggio = "Ausweisdokument"; break;
case "Tipo di documento di identità eliminato":	$messaggio = "Typ des Ausweisdokuments ge&ouml;scht"; break;
case "Nuovo tipo di documento di identità aggiunto":	$messaggio = "Neuer Typ eines Ausweisdokuments hinzugef&uuml;gt"; break;
case "Tipi di documento di identità predefiniti ripristinati":	$messaggio = "Vorgegebene Ausweistypen wieder hergestellt"; break;
case "Tipi di documento di identità cancellati":	$messaggio = "Ausweistyp gel&ouml;scht"; break;
case "Tipi di documento di identità importati":         $messaggio = "Ausweistypen importiert"; break;
case "Importa i documenti di identità":                 $messaggio = "Ausweisdokumente importieren"; break;
case "codice":                                          $messaggio = "Code"; break;
case "Nuova nazione":                                   $messaggio = "Neue Nation"; break;
case "Nuova regione/provincia":                         $messaggio = "Neue Region"; break;
case "Nuovo documento d'identità":                      $messaggio = "Neues Ausweisdokument"; break;
case "Nuova parentela":                                 $messaggio = "Neuer Verandtschaftsgrad"; break;
case "Elimina tutti":                                   $messaggio = "Alles l&ouml;schen"; break;
case "Ripristina predefiniti":                          $messaggio = "Vorgabewerte wiederherstellen"; break;
case "Città":                                           $messaggio = "St&auml;dte"; break;
case "Nuova città":                                     $messaggio = "Neue Stadt"; break;
case "Importa le città":                                $messaggio = "St&auml;dte importieren"; break;
case "Città cancellata":                                $messaggio = "Stadt gel&ouml;scht"; break;
case "Nuova città aggiunta":                            $messaggio = "Neue Stadt hinzugef&uuml;gt"; break;
case "Città predefinite ripristinate":                  $messaggio = "Vorgabewerte f&uuml;r St&auml;dte wiederhergestellt"; break;
case "Città cancellate":                                $messaggio = "St&auml;dte gel&ouml;scht"; break;
case "Città importate":                                 $messaggio = "St&auml;dte importiert"; break;
case "Titoli dei clienti":                              $messaggio = "Titel"; break;
case "sesso":                                           $messaggio = "Geschlecht"; break;
case "m":                                               $messaggio = "m"; break;
case "f":                                               $messaggio = "w"; break;
case "Titolo dei clienti eliminato":                    $messaggio = "Titel des Kunden gel&ouml;scht"; break;
case "Nuovo titolo dei clienti aggiunto":               $messaggio = "Neuer Titel hinzugef&uuml;gt"; break;
case "I dati della struttura sono stati cambiati":	$messaggio = "Unternehmensdaten wurden ge&auml;ndert"; break;
case "Dati della struttura":                            $messaggio = "Unternehmensdaten"; break;
case "Tipo":                                            $messaggio = "Art"; break;
case "Numero stelle":                                   $messaggio = "Anzahl Sterne"; break;
case "Nazione":                                         $messaggio = "Land"; break;
case "Comune":                                          $messaggio = "Stadt"; break;
case "Indirizzo":                                       $messaggio = "Adresse"; break;
case "CAP":                                             $messaggio = "Postleitzahl"; break;
case "Telefono":                                        $messaggio = "Telefon"; break;
case "Fax":                                             $messaggio = "Fax"; break;
case "Codice fiscale":                                  $messaggio = "Steuernummer"; break;
case "Partita iva":  				$messaggio = "USt-ID-Nummer"; break;
case "Modifica i dati della struttura":                 $messaggio = "Unternehmensdaten &auml;ndern"; break;
case "Clicca su un documento per modificarlo":          $messaggio = "Auf ein Dokument klicken um es zu &auml;ndern"; break;
case "Cambia l'ordine dei documenti":                   $messaggio = "Dokumentenreihenfolge &auml;ndern"; break;
case "Applica i cambiamenti":                           $messaggio = "&Auml;nderungen anwenden"; break;
case "Documento":                                       $messaggio = "Dokument"; break;
case "ex":                                              $messaggio = "ex"; break;
case "L'ordine dei documenti è stato cambiato":	$messaggio = "Dokumentenreihenfolge wurde ge&auml;ndert"; break;
case "Sito web":                                        $messaggio = "Webseite"; break;
case "Nome contatto":                                   $messaggio = "Ansprechpartner"; break;
case "l'ordine delle tariffe è stato cambiato":	$messaggio = "Preisreihenfolge wurde ge&auml;ndert"; break;
case "cambia l'ordine delle tariffe":  		$messaggio = "Preisreihenfolge &auml;ndern"; break;
case "tariffa":                                         $messaggio = "Tarif"; break;
case "valore predefinito a cui arrotondare le percentuali dei prezzi":	$messaggio = "Runden auf diesen Wert bei Prozentangaben bei Preisen"; break;
case "il":  					        $messaggio = "the"; break;
case "è stato cambiato":  			        $messaggio = "wurde ge&auml;ndert"; break;
case "password per la visualizzazione dei dati delle carte di credito":	$messaggio = "Kennwort um Kreditkartendaten anzusehen"; break;
case "attivata":  				        $messaggio = "aktiviert"; break;
case "disattivata":  				        $messaggio = "deaktiviert"; break;
case "cambia la password":  			        $messaggio = "Kennwort &auml;ndern"; break;
case "<b>Attenzione</b>: se si perde questa password non sarà più possibile leggere i dati delle carte di credito inserite":	$messaggio = "<b>Warnung</b>: Wenn Sie dieses kennwort verlieren, werden Sie niemals mehr auf die eingegebenen Kreditkartendaten zugreifen k&ouml;nnen"; break;
case "nuova password":  			$messaggio = "Neues Kennwort"; break;
case "ripetere password":  			$messaggio = "Kennwort wiederholen"; break;
case "attiva la password":  			$messaggio = "Kennwort aktivieren"; break;
case "le password inserite non coincidono":  	$messaggio = "Die eingegebenen Kennw&ouml;rter stimmen nicht &uuml;berein"; break;
case "errore nelle funzioni ssl":  		$messaggio = "Fehler in SSL-Funktionen"; break;
case "<b class=\"colred\">Attenzione</b>: tutti i dati delle carte di credito verranno cancellati":	$messaggio = "<b class=\"colred\">Warnung</b>: Alle Kreditkartendaten werden gel&ouml;scht"; break;
case "continua":  				$messaggio = "Weiter"; break;
case "vecchia password":  			$messaggio = "altes Kennwort"; break;
case "cambiata":  				$messaggio = "ge&auml;ndert"; break;
case "piano":  					$messaggio = "Etage"; break;
case "casa":  					$messaggio = "Haus"; break;
case "2°":  					$messaggio = "2."; break;
case "3°":  					$messaggio = "3."; break;
case "2° codice":  				$messaggio = "2. Code"; break;
case "3° codice":  				$messaggio = "3. Code"; break;
case "Tabella con i documenti salvati":  	$messaggio = "Tabelle mit gespeicherten Dokumenten"; break;
case "Il numero delle righe della tabella con i documenti salvati è stato cambiato":	$messaggio = "Die Tabelle mit den gespeicherten Dokumenten wurde ge&auml;ndert"; break;
case "documenti salvati":  			$messaggio = "Gespeicherte Dokumente"; break;
case "Scegli le righe aggiuntive da mostrare":	$messaggio = "Weitere Spalten zur Anzeige ausw&auml;hlen"; break;
case "tasse":  					$messaggio = "Steuern"; break;
case "trasferito in cassa":  			$messaggio = "&uuml;bertragen in Kasse"; break;
case "cambia le righe":  			$messaggio = "Spalten &auml;ndern"; break;
case "totale":  				$messaggio = "Gesamt"; break;
case "cognome ospite se differente":  		$messaggio = "Nachname Gast wenn unterschiedlich"; break;
case "Ragione sociale":  			$messaggio = "Firmenname"; break;
case "Nome delle unità da affittare":  		$messaggio = "Name der Vermietungseinheiten"; break;
case "nome personalizzato":  			$messaggio = "allgemeiner Name"; break;
case "singolare":  				$messaggio = "Einzahl"; break;
case "plurale":  				$messaggio = "Mehrzahl"; break;
case "genere":  				$messaggio = "Geschlecht"; break;
case "m":  					$messaggio = "m"; break;
case "f":  					$messaggio = "w"; break;
case "Il nome delle unità da affittare è stato cambiato":	$messaggio = "Der Name der Vermietungseinheit wurde ge&auml;ndert"; break;
case "Tabelle con le casse":  			$messaggio = "Kassentabelle"; break;
case "Il numero delle righe delle tabelle con le casse è stato cambiato":	$messaggio = "Die Anzahl Zeilen in den Kassentabellen wurde geändert"; break;
case "Elimina il documento":  			$messaggio = "Dokument l&ouml;schen"; break;
case "Sei sicuro di voler eliminare il documento":	$messaggio = "Sind Sie sicher, dass Sie das Dokument l&ouml;schen wollen:"; break;
case "Il documento è stato eliminato":	$messaggio = "Das Dokument wurde gel&ouml;scht"; break;
case "Campi da considerare per la ricerca dei clienti":	$messaggio = "Felder die bei der Suche nach Kunden ber&uuml;cksichtigt werden sollen"; break;
case "cognome":  				$messaggio = "Nachname"; break;
case "email":  					$messaggio = "E-Mail"; break;
case "nome":  					$messaggio = "Vorname"; break;
case "telefono":  				$messaggio = "Telefon"; break;
case "città":  					$messaggio = "Stadt"; break;
case "indirizzo":  				$messaggio = "Adresse"; break;
case "codice postale":  			$messaggio = "Postleitzahl"; break;
case "I campi da considerare per la ricerca dei clienti sono stati cambiati":	$messaggio = "Die Felder die bei der Suche ber&uuml;cksichtigt werden, wurden ge&auml;ndert"; break;
case "Personalizza":  				$messaggio = "Customize"; break;
case "Nome della valuta principale":  		$messaggio = "Name of the main currency"; break;
case "Regione/provincia":  			$messaggio = "Region"; break;
case "L'allineamento dei giorni con la disponibilità nella tabella dei mesi è stato cambiato":	$messaggio = "Days alignment with availability in months table has been changed"; break;
case "Allineare la disponibilità con le date di arrivo potrebbe generare confusione ed errori sulle date di partenza, si è sicuri di voler continuare?":	$messaggio = "Aligning availability with arrival dates may generate confusion and mistakes on departure dates, are you sure you want to continue?"; break;
case "nella regione/provincia di":  		$messaggio = "in region of"; break;
case "nella nazione":  				$messaggio = "in nation"; break;
case "Nome":  					$messaggio = "Name"; break;
case "valore a cui arrotondare le percentuali delle tasse e delle valute":	$messaggio = "rounding value for percentages of taxes and currencies"; break;
case "commissioni":  				$messaggio = "commissions"; break;
case "resto commissioni":  			$messaggio = "commissions rest"; break;
case "Le righe aggiuntive sono state cambiate":	$messaggio = "Extra rows have been changed"; break;
case "soldi prenotazioni cancellate":  		$messaggio = "deleted reservations money"; break;
case "URL del logo":  				$messaggio = "Logo URL"; break;
case "Nome delle unità singole":  		$messaggio = "Name of single units"; break;
case "Tabella dei messaggi":  			$messaggio = "Messages table"; break;
case "Il numero di righe della tabella dei messaggi è stato cambiato":	$messaggio = "The number of rows of the messages table has been changed"; break;
case "Scarica le email di richiesta disponibiltà dal server di posta":	$messaggio = "Download emails for availability enquiries from mail server"; break;
case "per es.":  				$messaggio = "e.g."; break;
case "Protocollo":  				$messaggio = "Protocol"; break;
case "Porta":  					$messaggio = "Port"; break;
case "default":  				$messaggio = "default"; break;
case "persoalizzata":  				$messaggio = "custom"; break;
case "Nome utente":  				$messaggio = "Username"; break;
case "Password":  				$messaggio = "Password"; break;
case "lasciare vuota per chiedere ogni volta":	$messaggio = "leave empty to ask each time"; break;
case "Identificazione messaggi di richiesta":	$messaggio = "Enquiry messages identification"; break;
case "Messaggio iniziale":  			$messaggio = "First post"; break;
case "Qualsiasi messaggio":  			$messaggio = "Any post"; break;
case "da":  					$messaggio = "from"; break;
case "con oggetto contenete":  			$messaggio = "with subject containing"; break;
case "I dati per lo scaricamento delle email sono sbagliati o incompleti":	$messaggio = "The data to download emails are wrong or incomplete"; break;
case "Lo scaricamento delle email di richiesta disponibiltà dal server di posta è stato cambiato":	$messaggio = "The download of emails for availability enquiries from mail server has been changed"; break;
case "Colori delle prenotazioni":  		$messaggio = "Reservations colors"; break;
case "Tutto pagato":  				$messaggio = "All paid"; break;
case "Caparra pagata":  			$messaggio = "Deposit paid"; break;
case "Confermate":  				$messaggio = "Confirmed"; break;
case "Non confermate":  			$messaggio = "Not confirmed"; break;
case "I colori sono sbagliati":  		$messaggio = "Colors are wrong"; break;
case "I colori delle prenotazioni sono stati cambiati":	$messaggio = "Reservations colors have been changed"; break;
case "Campi personalizzati dei clienti":  	$messaggio = "Custom fields for clients"; break;
case "Nuovo campo personalizzato dei clienti aggiunto":	$messaggio = "New custom field for clients added"; break;
case "Campo personalizzato dei clienti eliminato":	$messaggio = "Custom field for clients deleted"; break;
case "tipo":  					$messaggio = "type"; break;
case "booleano":  				$messaggio = "boolean"; break;
case "testo":  					$messaggio = "text"; break;
case "Il campo personalizzato contiene caratteri non consentiti":	$messaggio = "The custom field contains not allowed characters"; break;
case "Gestire anche i codici CVC delle carte di credito":	$messaggio = "Manage the CVC codes from credit cards too"; break;
case "Esonero di responsabilità":  		$messaggio = "Disclaimer"; break;
case "la gestione dei codici CVC avverrà sotto la propria responsabilità, essendo a conoscenza che gli standard di sicurezza PCI ne vietano la registrazione":	$messaggio = "the CVC codes will be managed under your own responsibility, being aware that PCI security standards forbid their storage"; break;
case "L'accettazione di questa clausola conferma che gli sviluppatori di questo software sono liberi da ogni responsibilità sulla sicurezza di questi dati":	$messaggio = "Accepting this clause confirms that the developers of this software are free from all responsibilities regarding the security of these data"; break;
case "Accetto":  				$messaggio = "I Accept"; break;
case "Declino":  				$messaggio = "I Decline"; break;
case "La gestione dei codici cvc è stata cambiata":	$messaggio = "The management of CVC codes has been changed"; break;
case "Scegli le righe con i totali da mostrare":	$messaggio = "Choose which totals to show in rows"; break;
case "giornaliero":  				$messaggio = "daily"; break;
case "mensile":  				$messaggio = "montly"; break;
case "tabella":  				$messaggio = "table"; break;
case "Le righe da mostrare nelle tabelle delle casse sono state cambiate":	$messaggio = "Rows shown in cashobxes tables have been changed"; break;
case "partenze e prenotazioni correnti":  	$messaggio = "departures and current reservations"; break;
case "Commenti personalizzati delle prenotazioni":	$messaggio = "Custom comments for reservations"; break;
case "Commento personalizzato della prenotazione eliminato":	$messaggio = "Custom comment for reservation deleted"; break;
case "Nuovo commento personalizzato della prenotazione aggiunto":	$messaggio = "New custom comment for reservation added"; break;
case "Punto vendita ed inventario":  		$messaggio = "Point of sale and inventory"; break;
case "Ordinamento nell'inventario e punto vendita":	$messaggio = "Sorting in inventory and point of sale"; break;
case "alfabetico":  				$messaggio = "alphabetically"; break;
case "per ordine di inserimento":  		$messaggio = "by insertion order"; break;
case "Tasti per operazioni nel punto vendita":	$messaggio = "Buttons for operations in point of sale"; break;
case "L'ordinamento nell'inventario e nel punto vendita è stato cambiato":	$messaggio = "Sorting in inventory and point of sale has been changed"; break;
case "I tasti per operazioni nel punto vendita sono stati cambiati":	$messaggio = "Buttons for operations in point of sale have been changed"; break;
case "Attenzione":  				$messaggio = "Warning"; break;
case "i link per l'esportazione dei calendari in formato ical sono cambiati, ricordarsi di aggiornarli sui calendari esterni":	$messaggio = "the links to export calendars in ical format have changed, remember to update them on external calendars"; break;
case "La tariffa":  				$messaggio = "Rate"; break;
case "è ancora in uso nelle interconnessioni":	$messaggio = "is still in use in interconnections"; break;
case "almeno 8 caratteri, con lettere e numeri o simboli":	$messaggio = "at least 8 characters, with letters and numbers or symbols"; break;
case "diversa dalle ultime":  			$messaggio = "different from last"; break;
case "Condizioni Generali di Contratto":  	$messaggio = "General Terms and Conditions"; break;
case "del servizio di memorizzazione delle carte di credito":	$messaggio = "of the credit cards storage service"; break;
case "La password non è stata modificata":  	$messaggio = "The password has not been modified"; break;
case "password errata":  			$messaggio = "wrong password"; break;
case "adulto":  				$messaggio = "adult"; break;
case "adulti":  				$messaggio = "adults"; break;
case "bambino":  				$messaggio = "child"; break;
case "bambini":  				$messaggio = "children"; break;
case "Numero di tipologie di persone":  	$messaggio = "Number of people types"; break;
case "Tipologia":  				$messaggio = "Type"; break;
case "Può essere ospite principale":  		$messaggio = "Can be main guest"; break;
case "Prezzo in percentuale del prezzo per persona":	$messaggio = "Price in percentage of per person price"; break;
case "arrotondato a":  				$messaggio = "rounded to"; break;
case "Modifica le tipologie di persone":  	$messaggio = "Modify people types"; break;
case "Il numero di tipologie di persone è sbagliato":	$messaggio = "The number of people types is wrong"; break;
case "Il numero di tipologie di persone è stato cambiato":	$messaggio = "The number of people types has been changed"; break;
case "I dati inseriti non sono corretti":  	$messaggio = "Inserted data are incorrect"; break;
case "Le tipologie di persone sono state modificate":	$messaggio = "The people types have been modified"; break;
case "Cambia per tutti gli utenti":  		$messaggio = "Change for all users"; break;
case "Modifica le tipologie di persone per tutti gli utenti":	$messaggio = "Modify people types for all users"; break;
case "tipi di persona":  			$messaggio = "person types"; break;
case "Valuta secondaria chiamata":  		$messaggio = "Secundary currency called"; break;
case "nuova valuta":  				$messaggio = "new currency"; break;
case "con arrotondamento":  			$messaggio = "with rounding"; break;
case "Aggiungi per tutti gli utenti":  		$messaggio = "Add for all users"; break;
case "Elimina la valuta":  			$messaggio = "Delete the currency"; break;
case "Elimina":  				$messaggio = "Delete"; break;
case "Elimina per tutti gli utenti":  		$messaggio = "Delete for all users"; break;
case "La nuova valuta secondaria è stata aggiunta":	$messaggio = "The new secundary currency has been addded"; break;
case "La valuta secondaria":  			$messaggio = "The secundary currency"; break;
case "è stata modificata":  			$messaggio = "has been modified"; break;
case "è stata eliminata":  			$messaggio = "has been deleted"; break;
case "La cartella":  				$messaggio = "The directory"; break;
case "è un duplicato":  			$messaggio = "is a duplicate"; break;
case "le seguenti pagine web verranno cancellate":	$messaggio = "the following web pages will be deleted"; break;
case "le tipologie di persone rimosse erano presenti in alcuni costi aggiuntivi, questi costi vanno aggiornati manualmente se necessario":	$messaggio = "removed person types were present in some extra costs, eventually these costs must be updated manually"; break;
case "Utilizzo dei cookies per la gestione delle sessioni attivato":	$messaggio = "Use of cookies for session handling enabled"; break;
case "Utilizzo dei cookies per la gestione delle sessioni disattivato":	$messaggio = "Use of cookies for session handling disabled"; break;
case "Percorso al file autoload.php di phpmailer":	$messaggio = "Path to autoload.php file for phpmailer"; break;
case "per inviare email attraverso un server remoto":	$messaggio = "to send emails through a remote server"; break;
case "Per inviare le email usare":  		$messaggio = "To send emails use"; break;
case "il server locale":  			$messaggio = "the local server"; break;
case "un server remoto":  			$messaggio = "a remote server"; break;
case "Server di posta SMTP":  			$messaggio = "SMTP mail server"; break;
case "Sicurezza connessione":  			$messaggio = "Connection security"; break;
case "nessuna":  				$messaggio = "no one"; break;
case "Il percorso al file autoload.php di phpmailer è stato cambiato":	$messaggio = "The path to autoload.php file for phpmailer has been changed"; break;
case "Il file inserito <span class=\"colred\">non carica phpmailer</span> correttamente":	$messaggio = "The inserted file <span class=\"colred\">does not load phpmailer</span> correctly"; break;
case "Il metodo per inviare le email è stato cambiato":	$messaggio = "The method to send emails has been changed"; break;
case "Connessione fallita":  			$messaggio = "Falied connection"; break;
case "EHLO fallito":  				$messaggio = "Failed EHLO"; break;
case "Connessione cifrata STARTTLS fallita":  	$messaggio = "STARTTLS encrypted connection failed"; break;
case "EHLO dopo STARTTLS fallito":  		$messaggio = "EHLO after STARTTLS failed"; break;
case "Autenticazione fallita":  		$messaggio = "Failed authentication"; break;
case "I dati per il collegamento al server SMTP sono <span class=\"colred\">sbagliati o incompleti</span>":	$messaggio = "The data to connect to the SMTP server are <span class=\"colred\">wrong or incomplete</span>"; break;
case "I dati per il collegamento al server SMTP sono stati aggiornati":	$messaggio = "The data to connect to the SMTP server have been updated"; break;
case "controllando SPF":  			$messaggio = "checking SPF"; break;
case "Attualmente SPF è configurato correttamente sul dominio della email della struttura":	$messaggio = "Currently SPF is correctly configured on the domain of the property email"; break;
case "Attualmente <span class=\"colred\">SPF non è configurato correttamente</span> sul dominio della email della struttura":	$messaggio = "Currently <span class=\"colred\">SPF is not configured correctly</span> on the domain of the property email"; break;
case "Il mascheramento delle email verrà attivato solo se nel DNS del dominio dell'email del mittente c'è un record TXT per SPF contenente":	$messaggio = "Email masquerading will be activated only if in the DNS of the domain of the sender's email there is a TXT record for SPF containing"; break;
case "Il dominio":  				$messaggio = "The domain"; break;
case "non ha nessun record per SPF":  		$messaggio = "has no record for SPF"; break;
case "nella gestione del suo DNS va aggiunto un record TXT contenente un testo come questo":	$messaggio = "in the management of your DNS you must add a TXT record containing a text like this"; break;
case "Questo è il record SPF attuale del dominio":	$messaggio = "This is the current SPF record of the domain"; break;
case "questo record TXT va modificato nella gestione del DNS del dominio":	$messaggio = "this TXT record must be modified in the management of DNS of the domain"; break;
case "sostituendolo con un testo come questo":	$messaggio = "replacing it with a text like this"; break;
case "Dopo la modifica potrebbero volerci alcune ore affinchè l'aggiornamento sia attivo":	$messaggio = "After the change it may take a few hours for the update to take effect"; break;
case "Formato di nomi e cognomi":  		$messaggio = "Format of names and surnames"; break;
case "non modificare il formato inserito":  	$messaggio = "don't modify inserted format"; break;
case "prima lettera maiuscola, altre lettere minuscole":	$messaggio = "first letter uppercase, other letters lowercase"; break;
case "prima lettera maiuscola, non modificare altre lettere":	$messaggio = "first letter uppercase, do not change other letters"; break;
case "tutte lettere maiuscole":  		$messaggio = "all letters uppercase"; break;
case "tutte lettere minuscole":  		$messaggio = "all letters lowercase"; break;
case "Il formato di inserimento dei nomi e cognimi è stato cambiato":	$messaggio = "The format for inserting names and surnames has been changed"; break;
case "Per il proprio indirizzo email si sta usando un provider pubblico":	$messaggio = "For your email address you are using a public provider"; break;
case "si consiglia quindi di":  		$messaggio = "it is therefore advisable to"; break;
case "configurare il loro server remoto smtp":	$messaggio = "configure their remote smtp server"; break;
case "per inviare email":  			$messaggio = "to avoid that emails sent"; break;
case "da hoteldruid":  				$messaggio = "from hoteldruid"; break;
case "senza che vengano considerate come spam":	$messaggio = "are considered as spam"; break;
case "percorsi relativi":  			$messaggio = "paths relative"; break;
case "Secondo cognome disattivato":  		$messaggio = "Second surname disabled"; break;
case "Secondo cognome attivato":  		$messaggio = "Second surname enabled"; break;
case "Fuso orario":  				$messaggio = "Time zone"; break;
case "nessun fuso orario":  			$messaggio = "no time zone"; break;
case "Si possono creare solo cartelle con nome composto da lettere e numeri":	$messaggio = "Only folders with names that contain letters and numbers can be created"; break;
case "la seguente cartella verrà creata":  	$messaggio = "the following folder will be created"; break;
case "":  		$messaggio = ""; break;
case "":  		$messaggio = ""; break;

} # fine switch ($messaggio)

?>
